==> cetus-8.0.30.tgz: package/events-sns/index.js <==
utilities = require('../utilities/index');

let AWS = require('aws-sdk');
let snsClient = null;
// let env = process.env.NODE_ENV || 'development',

// AWS.config.update({
//   accessKeyId: process.env.AWS_EVENTS_SNS_ID,
//   secretAccessKey: process.env.AWS_EVENTS_SNS_SECRET,
//   region: 'us-west-2'
// });

function init(){
    utilities.logger.info('framework/notify/bin/AWSSNS init');
    snsClient = new AWS.SNS({timeout: 200});
};

function wrapInTry(func) {
  let result;
  try {
    result = func();
  } catch (e) {
    logger.error(e);
  } finally {
    return result;
  }
}

function buildPayload(dataObj, results) {
  const { args, req } = dataObj.data;
  let cleanedApiResult = {}
  if (results.toString().length < 400) {
    cleanedApiResult = results;
  } else {
    cleanedApiResult.error = results.error;
    if (results.item) {
      cleanedApiResult.item = { _id: results.item._id };
    }
    if (results._person) {
      cleanedApiResult._person = results._person;
    }
  }
  return {
    default: JSON.stringify(
      {
        url: req.route.path,
        args: args,
        session: req.session,
        header: req.headers,
        eventTime: Date.now(),
        // results: results.item ? { item: { _id: results.item._id }, error: results.error } : { error: results.error, status: 'removed to avoid message to long for SNS' },
        results: cleanedApiResult
      }
    )
  };
}

function publish(data, result) {
  const dataObj = { data };
  const payload = buildPayload(dataObj, result);
  wrapInTry(() => {
    snsClient.publish({ TargetArn: process.env.AWS_EVENTS_ARN, Message: JSON.stringify(payload), MessageStructure: 'json' }).promise().then(() => { }).catch((err) => {
      utilities.logger.error(err)
    });
  }
  );
};

module.exports = {
  init,
  publish,
};

==> cetus-8.0.32.tgz: package/events-sns/index.js <==
utilities = require('../utilities/index');

let AWS = require('aws-sdk');
let snsClient = null;
// let env = process.env.NODE_ENV || 'development',

// AWS.config.update({
//   accessKeyId: process.env.AWS_EVENTS_SNS_ID,
//   secretAccessKey: process.env.AWS_EVENTS_SNS_SECRET,
//   region: 'us-west-2'
// });

function init() {
  utilities.logger.info('framework/notify/bin/AWSSNS init');
  snsClient = new AWS.SNS({ timeout: 200 });
};

function wrapInTry(func) {
  let result;
  try {
    result = func();
  } catch (e) {
    logger.error(e);
  } finally {
    return result;
  }
}

function buildPayload(dataObj, results) {
  const { args, req, userPlatform, appVersion } = dataObj.data;

  let cleanedApiResult = {}
  if (results.toString().length < 400) {
    cleanedApiResult = results;
  } else {
    cleanedApiResult.error = results.error;
    if (results.item) {
      cleanedApiResult.item = { _id: results.item._id };
    }
    if (results._person) {
      cleanedApiResult._person = results._person;
    }
  }

  return {
    default: JSON.stringify(
      {
        url: req.route.path,
        args: args,
        session: req.session,
        header: req.headers,
        userPlatform,
        appVersion,
        eventTime: Date.now(),
        // results: results.item ? { item: { _id: results.item._id }, error: results.error } : { error: results.error, status: 'removed to avoid message to long for SNS' },
        results: cleanedApiResult
      }
    )
  };
}

function publish(data, result) {
  const dataObj = { data };
  const payload = buildPayload(dataObj, result);
  wrapInTry(() => {
    snsClient.publish({ TargetArn: process.env.AWS_EVENTS_ARN, Message: JSON.stringify(payload), MessageStructure: 'json' }).promise().then(() => { }).catch((err) => {
      utilities.logger.error(err)
    });
  }
  );
};

module.exports = {
  init,
  publish,
};
